@@ -9,7 +9,7 @@ import requests
 from openpecha.core.annotation import Page, Span
 from openpecha.core.layer import Layer, LayerEnum
 from openpecha.formatters import BaseFormatter
-from openpecha.utils import gzip_str
+from openpecha.utils import gzip_str, dump_yaml
 
 
 class GoogleOCRFormatter(BaseFormatter):
@@ -53,8 +53,10 @@ class GoogleOCRFormatter(BaseFormatter):
             page = Page(span=span, imgnum=n_pg, reference=page_ref)
             anns[uuid] = page
 
-        layer = Layer(annotation_type=LayerEnum("pagination"), annotations=anns)
-        result = {"pagination": json.loads(layer.json(exclude_none=True))}
+        layer = Layer(annotation_type=LayerEnum("Pagination"), annotations=anns)
+        result = {
+            LayerEnum("Pagination").value: json.loads(layer.json(exclude_none=True))
+        }
 
         return result
 
@@ -255,13 +257,13 @@ class GoogleOCRFormatter(BaseFormatter):
             vol_layer_path.mkdir(exist_ok=True)
             for layer, ann in formatted_layers.items():
                 layer_fn = vol_layer_path / f"{layer}.yml"
-                self.dump(ann, layer_fn)
+                dump_yaml(ann, layer_fn)
 
             self.set_vols_meta(vol_path.name, f"{base_id}.txt")
 
         # create meta.yml
         meta_fn = self.dirs["opf_path"] / "meta.yml"
-        self.dump(self.get_metadata(input_path.name), meta_fn)
+        dump_yaml(self.get_metadata(input_path.name), meta_fn)
 
         return self.dirs["opf_path"].parent
 
